@@ -26,6 +26,8 @@ try:
 except ImportError:
     pdf2image = None
 
+from .common import is_notebook
+
 # Special tokens redered with a LaTeX macro
 _latex_symbols = ['alpha',
                   'beta',
@@ -195,25 +197,6 @@ def _sliding_time(t, window_size=4, step_size=2, criterion="mean"):
         raise ValueError("Invalid criterion")
 
 
-def _is_notebook():
-    """Detect if running in a notebook"""
-    # Not sure this covers
-    try:
-        ipython_module = get_ipython().__module__
-        if ipython_module in ['ipykernel.zmqshell', 'google.colab._shell']:
-            # Surely a notebook
-            return True
-        elif ipython_module in ['IPython.terminal.interactiveshell']:
-            # Surely not a notebook
-            return False
-        else:
-            warnings.warn("Unknown iPython detected: %s. Assuming not a notebook.")
-            return False
-    except NameError:
-        # Surely not iPython
-        return False
-
-
 def _escape_state(s):
     return s.replace("_", "-")
 
@@ -386,7 +369,8 @@ class _Model:
         Args:
             data (list of list of float): 2D array whose first index is the component (e.g., S, I, R....) and its
                                           second index is the time.
-            t (list of float): Time mesh. Must be consistent with data.
+            t (list of float): Time mesh. Must be consistent with data. Explicitly provide None to use an integer mesh
+                               starting from 0.
             initial_pars (list of float): Initial values of the parameters.
             target (str): Metric to reproduce. Available options are:
                           - "y": The curves themselves.
@@ -411,7 +395,10 @@ class _Model:
         # Time to first index, component to second
         data = np.asarray(data).T
 
-        t = np.asarray(t)
+        if t is None:
+            t = np.asarray(list(range(len(data[0]))))
+        else:
+            t = np.asarray(t)
 
         if target == "dy":
             # Fit to increments
@@ -458,7 +445,8 @@ class _Model:
         Args:
             data (list of list of float): 2D array whose first index is the component (e.g., S, I, R....) and its
                                           second index is the time.
-            t (list of float): Time mesh. Must be consistent with data.
+            t (list of float): Time mesh. Must be consistent with data. Explicitly provide None to use an integer mesh
+                               starting from 0.
             initial_pars (list of float): Initial values of the parameters.
             window_size (int): Window size (number of time values in each window).
             step_size (int): Window step size (number of time values between windows).
@@ -477,6 +465,8 @@ class _Model:
             pd.DataFrame: A dataframe with the fits in each of the windows.
 
         """
+        if t is None:
+            t = np.asarray(list(range(len(data[0]))))
         values = np.asarray(list(self._best_sliding_fit(data, t, initial_pars, window_size, step_size, target=target,
                                                         component_weights=component_weights, ls_kwargs=ls_kwargs)))
         t2 = _sliding_time(t, window_size=window_size, step_size=step_size, criterion=time_criterion)
@@ -547,7 +537,7 @@ class _Model:
         style = {**style, **kwargs}
 
         # network2tikz shows a pdf in an external editor if filename is None. Change if running in a notebook
-        if filename is None and _is_notebook():
+        if filename is None and is_notebook():
             if pdf2image is None:
                 warnings.warn("Image will be shown externally since pdf2image is not available")
                 # Default behaviour below
